==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Sticky/Sticky.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Inject, Prop, Watch, Component } from 'vue-property-decorator';
import { hiddenContentStyle } from '@uifabric/styling';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { StickyPositionType } from './Sticky.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var Sticky = function (_BaseComponent) {
  _inherits(Sticky, _BaseComponent);

  var _super = _createSuper(Sticky);

  function Sticky() {
    var _this;

    _classCallCheck(this, Sticky);

    _this = _super.apply(this, arguments);
    _this.hiddenContentStyle = hiddenContentStyle;
    _this.isStickyTop = false;
    _this.isStickyBottom = false;
    _this.distanceFromTop = 0;
    _this.activeElement = null;
    return _this;
  }

  _createClass(Sticky, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var canStickyTop = this.canStickyTop,
          canStickyBottom = this.canStickyBottom,
          isStickyTop = this.isStickyTop,
          isStickyBottom = this.isStickyBottom,
          stickyClassName = this.stickyClassName;
      return h("div", {
        "ref": "root"
      }, [canStickyTop && h("div", {
        "ref": "stickyContentTop",
        "attrs": {
          "aria-hidden": !isStickyTop
        },
        "style": {
          pointerEvents: isStickyTop ? 'auto' : 'none'
        }
      }, [h("div", {
        "style": this.getStickyPlaceholderHeight(isStickyTop)
      })]), canStickyBottom && h("div", {
        "ref": "stickyContentBottom",
        "attrs": {
          "aria-hidden": !isStickyBottom
        },
        "style": {
          pointerEvents: isStickyBottom ? 'auto' : 'none'
        }
      }, [h("div", {
        "style": this.getStickyPlaceholderHeight(isStickyBottom)
      })]), h("div", {
        "ref": "placeHolder",
        "style": this.getNonStickyPlaceholderHeightAndWidth()
      }, [(isStickyTop || isStickyBottom) && h("span", {
        "style": hiddenContentStyle
      }, [this.$slots["default"]]), h("div", {
        "ref": "nonStickyContent",
        "attrs": {
          "aria-hidden": isStickyTop || isStickyBottom
        },
        "class": isStickyTop || isStickyBottom ? stickyClassName : undefined,
        "style": this.getContentStyles(isStickyTop || isStickyBottom)
      }, [this.$slots["default"]])])]);
    }
  }, {
    key: "root",
    value: function root() {
      return this.$refs.root;
    }
  }, {
    key: "syncScroll",
    value: function syncScroll(container) {
      var nonStickyContent = this.$refs.nonStickyContent;

      if (nonStickyContent && this.isScrollSynced) {
        nonStickyContent.scrollLeft = container.scrollLeft;
      }
    }
  }, {
    key: "mounted",
    value: function mounted() {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      scrollablePane.subscribe(this._onScrollEvent);
      scrollablePane.addSticky(this);
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      scrollablePane.unsubscribe(this._onScrollEvent);
      scrollablePane.removeSticky(this);
    }
  }, {
    key: "onDistanceFromTopChanged",
    value: function onDistanceFromTopChanged(newVal, oldVal) {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      if (newVal !== oldVal) {
        scrollablePane.sortSticky(this, true);
        scrollablePane.syncScrollSticky(this);
      }
    }
  }, {
    key: "onIsStickyTopChanged",
    value: function onIsStickyTopChanged(newVal, oldVal) {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      if (newVal !== oldVal) {
        if (this.activeElement) {
          this.activeElement.focus();
        }

        scrollablePane.updateStickyRefHeights();
        scrollablePane.syncScrollSticky(this);
      }
    }
  }, {
    key: "onIsStickyBottomChanged",
    value: function onIsStickyBottomChanged(newVal, oldVal) {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      if (newVal !== oldVal) {
        if (this.activeElement) {
          this.activeElement.focus();
        }

        scrollablePane.updateStickyRefHeights();
        scrollablePane.syncScrollSticky(this);
      }
    }
  }, {
    key: "addSticky",
    value: function addSticky(stickyContent) {
      if (this.$refs.nonStickyContent) {
        stickyContent.appendChild(this.$refs.nonStickyContent);
      }
    }
  }, {
    key: "resetSticky",
    value: function resetSticky() {
      if (this.$refs.nonStickyContent && this.$refs.placeHolder) {
        this.$refs.placeHolder.appendChild(this.$refs.nonStickyContent);
      }
    }
  }, {
    key: "setDistanceFromTop",
    value: function setDistanceFromTop(container) {
      var distanceFromTop = this._getNonStickyDistanceFromTop(container);

      this.distanceFromTop = distanceFromTop;
    }
  }, {
    key: "getContentStyles",
    value: function getContentStyles(isSticky) {
      return {
        backgroundColor: this.stickyBackgroundColor || this._getBackground(),
        overflow: isSticky ? 'hidden' : ''
      };
    }
  }, {
    key: "getStickyPlaceholderHeight",
    value: function getStickyPlaceholderHeight(isSticky) {
      var height = this.$refs.nonStickyContent ? this.$refs.nonStickyContent.offsetHeight : 0;
      return {
        visibility: isSticky ? 'hidden' : 'visible',
        height: isSticky ? 0 : height
      };
    }
  }, {
    key: "getNonStickyPlaceholderHeightAndWidth",
    value: function getNonStickyPlaceholderHeightAndWidth() {
      var isStickyTop = this.isStickyTop,
          isStickyBottom = this.isStickyBottom;

      if (isStickyTop || isStickyBottom) {
        var height = 0;
        var width = 0;

        if (this.$refs.nonStickyContent && this.$refs.nonStickyContent.firstElementChild) {
          height = this.$refs.nonStickyContent.offsetHeight;
          width = this.$refs.nonStickyContent.firstElementChild.scrollWidth + (this.$refs.nonStickyContent.firstElementChild.offsetWidth - this.$refs.nonStickyContent.firstElementChild.clientWidth);
        }

        return {
          height: height,
          width: width
        };
      } else {
        return {};
      }
    }
  }, {
    key: "_onScrollEvent",
    value: function _onScrollEvent(container, footerStickyContainer) {
      if (this.$refs.root && this.$refs.nonStickyContent) {
        var distanceFromTop = this._getNonStickyDistanceFromTop(container);

        var isStickyTop = false;
        var isStickyBottom = false;

        if (this.canStickyTop) {
          var distanceToStickTop = distanceFromTop - this._getStickyDistanceFromTop();

          isStickyTop = distanceToStickTop < container.scrollTop;
        }

        if (this.canStickyBottom && container.clientHeight - footerStickyContainer.offsetHeight <= distanceFromTop) {
          isStickyBottom = distanceFromTop - Math.floor(container.scrollTop) >= this._getStickyDistanceFromTopForFooter(container, footerStickyContainer);
        }

        if (document.activeElement && this.$refs.nonStickyContent.contains(document.activeElement) && (this.isStickyTop !== isStickyTop || this.isStickyBottom !== isStickyBottom)) {
          this.activeElement = document.activeElement;
        } else {
          this.activeElement = undefined;
        }

        this.isStickyTop = this.canStickyTop && isStickyTop;
        this.isStickyBottom = isStickyBottom;
        this.distanceFromTop = distanceFromTop;
      }
    }
  }, {
    key: "_getStickyDistanceFromTop",
    value: function _getStickyDistanceFromTop() {
      var distance = 0;

      if (this.$refs.stickyContentTop) {
        distance = this.$refs.stickyContentTop.offsetTop;
      }

      return distance;
    }
  }, {
    key: "_getStickyDistanceFromTopForFooter",
    value: function _getStickyDistanceFromTopForFooter(container, footerStickyVisibleContainer) {
      var distance = 0;

      if (this.$refs.stickyContentBottom) {
        distance = container.clientHeight - footerStickyVisibleContainer.offsetHeight + this.$refs.stickyContentBottom.offsetTop;
      }

      return distance;
    }
  }, {
    key: "_getNonStickyDistanceFromTop",
    value: function _getNonStickyDistanceFromTop(container) {
      var distance = 0;
      var currElem = this.$refs.root;

      if (currElem) {
        while (currElem && currElem.offsetParent !== container) {
          distance += currElem.offsetTop;
          currElem = currElem.offsetParent;
        }

        if (currElem && currElem.offsetParent === container) {
          distance += currElem.offsetTop;
        }
      }

      return distance;
    }
  }, {
    key: "_getBackground",
    value: function _getBackground() {
      if (!this.$refs.root) {
        return undefined;
      }

      var curr = this.$refs.root;

      while (window.getComputedStyle(curr).getPropertyValue('background-color') === 'rgba(0, 0, 0, 0)' || window.getComputedStyle(curr).getPropertyValue('background-color') === 'transparent') {
        if (curr.tagName === 'HTML') {
          return undefined;
        }

        if (curr.parentElement) {
          curr = curr.parentElement;
        }
      }

      return window.getComputedStyle(curr).getPropertyValue('background-color');
    }
  }, {
    key: "canStickyTop",
    get: function get() {
      return this.stickyPosition === StickyPositionType.Both || this.stickyPosition === StickyPositionType.Header;
    }
  }, {
    key: "canStickyBottom",
    get: function get() {
      return this.stickyPosition === StickyPositionType.Both || this.stickyPosition === StickyPositionType.Footer;
    }
  }]);

  return Sticky;
}(BaseComponent);

__decorate([Inject({
  from: 'context',
  "default": undefined
}), __metadata("design:type", Object)], Sticky.prototype, "context", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], Sticky.prototype, "stickyClassName", void 0);

__decorate([Prop({
  type: String,
  "default": null
}), __metadata("design:type", String)], Sticky.prototype, "stickyBackgroundColor", void 0);

__decorate([Prop({
  type: Number,
  "default": StickyPositionType.Both
}), __metadata("design:type", Number)], Sticky.prototype, "stickyPosition", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], Sticky.prototype, "isScrollSynced", void 0);

__decorate([Watch('distanceFromTop'), __metadata("design:type", Function), __metadata("design:paramtypes", [Number, Number]), __metadata("design:returntype", void 0)], Sticky.prototype, "onDistanceFromTopChanged", null);

__decorate([Watch('isStickyTop'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], Sticky.prototype, "onIsStickyTopChanged", null);

__decorate([Watch('isStickyBottom'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], Sticky.prototype, "onIsStickyBottomChanged", null);

Sticky = __decorate([Component({})], Sticky);

export { Sticky };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Sticky/Sticky.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Inject, Prop, Watch, Component } from 'vue-property-decorator';
import { hiddenContentStyle } from '@uifabric/styling';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.number.constructor';
import { StickyPositionType } from './Sticky.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var Sticky = function (_BaseComponent) {
  _inherits(Sticky, _BaseComponent);

  var _super = _createSuper(Sticky);

  function Sticky() {
    var _this;

    _classCallCheck(this, Sticky);

    _this = _super.apply(this, arguments);
    _this.hiddenContentStyle = hiddenContentStyle;
    _this.isStickyTop = false;
    _this.isStickyBottom = false;
    _this.distanceFromTop = 0;
    _this.activeElement = null;
    return _this;
  }

  _createClass(Sticky, [{
    key: "render",
    value: function render() {
      var h = arguments[0];
      var canStickyTop = this.canStickyTop,
          canStickyBottom = this.canStickyBottom,
          isStickyTop = this.isStickyTop,
          isStickyBottom = this.isStickyBottom,
          stickyClassName = this.stickyClassName;
      return h("div", {
        "ref": "root"
      }, [canStickyTop && h("div", {
        "ref": "stickyContentTop",
        "attrs": {
          "aria-hidden": !isStickyTop
        },
        "style": {
          pointerEvents: isStickyTop ? 'auto' : 'none'
        }
      }, [h("div", {
        "style": this.getStickyPlaceholderHeight(isStickyTop)
      })]), canStickyBottom && h("div", {
        "ref": "stickyContentBottom",
        "attrs": {
          "aria-hidden": !isStickyBottom
        },
        "style": {
          pointerEvents: isStickyBottom ? 'auto' : 'none'
        }
      }, [h("div", {
        "style": this.getStickyPlaceholderHeight(isStickyBottom)
      })]), h("div", {
        "ref": "placeHolder",
        "style": this.getNonStickyPlaceholderHeightAndWidth()
      }, [(isStickyTop || isStickyBottom) && h("span", {
        "style": hiddenContentStyle
      }, [this.$slots.default]), h("div", {
        "ref": "nonStickyContent",
        "attrs": {
          "aria-hidden": isStickyTop || isStickyBottom
        },
        "class": isStickyTop || isStickyBottom ? stickyClassName : undefined,
        "style": this.getContentStyles(isStickyTop || isStickyBottom)
      }, [this.$slots.default])])]);
    }
  }, {
    key: "root",
    value: function root() {
      return this.$refs.root;
    }
  }, {
    key: "syncScroll",
    value: function syncScroll(container) {
      var nonStickyContent = this.$refs.nonStickyContent;

      if (nonStickyContent && this.isScrollSynced) {
        nonStickyContent.scrollLeft = container.scrollLeft;
      }
    }
  }, {
    key: "mounted",
    value: function mounted() {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      scrollablePane.subscribe(this._onScrollEvent);
      scrollablePane.addSticky(this);
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      scrollablePane.unsubscribe(this._onScrollEvent);
      scrollablePane.removeSticky(this);
    }
  }, {
    key: "onDistanceFromTopChanged",
    value: function onDistanceFromTopChanged(newVal, oldVal) {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      if (newVal !== oldVal) {
        scrollablePane.sortSticky(this, true);
        scrollablePane.syncScrollSticky(this);
      }
    }
  }, {
    key: "onIsStickyTopChanged",
    value: function onIsStickyTopChanged(newVal, oldVal) {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      if (newVal !== oldVal) {
        if (this.activeElement) {
          this.activeElement.focus();
        }

        scrollablePane.updateStickyRefHeights();
        scrollablePane.syncScrollSticky(this);
      }
    }
  }, {
    key: "onIsStickyBottomChanged",
    value: function onIsStickyBottomChanged(newVal, oldVal) {
      var scrollablePane = this.context.scrollablePane;

      if (!scrollablePane) {
        return;
      }

      if (newVal !== oldVal) {
        if (this.activeElement) {
          this.activeElement.focus();
        }

        scrollablePane.updateStickyRefHeights();
        scrollablePane.syncScrollSticky(this);
      }
    }
  }, {
    key: "addSticky",
    value: function addSticky(stickyContent) {
      if (this.$refs.nonStickyContent) {
        stickyContent.appendChild(this.$refs.nonStickyContent);
      }
    }
  }, {
    key: "resetSticky",
    value: function resetSticky() {
      if (this.$refs.nonStickyContent && this.$refs.placeHolder) {
        this.$refs.placeHolder.appendChild(this.$refs.nonStickyContent);
      }
    }
  }, {
    key: "setDistanceFromTop",
    value: function setDistanceFromTop(container) {
      var distanceFromTop = this._getNonStickyDistanceFromTop(container);

      this.distanceFromTop = distanceFromTop;
    }
  }, {
    key: "getContentStyles",
    value: function getContentStyles(isSticky) {
      return {
        backgroundColor: this.stickyBackgroundColor || this._getBackground(),
        overflow: isSticky ? 'hidden' : ''
      };
    }
  }, {
    key: "getStickyPlaceholderHeight",
    value: function getStickyPlaceholderHeight(isSticky) {
      var height = this.$refs.nonStickyContent ? this.$refs.nonStickyContent.offsetHeight : 0;
      return {
        visibility: isSticky ? 'hidden' : 'visible',
        height: isSticky ? 0 : height
      };
    }
  }, {
    key: "getNonStickyPlaceholderHeightAndWidth",
    value: function getNonStickyPlaceholderHeightAndWidth() {
      var isStickyTop = this.isStickyTop,
          isStickyBottom = this.isStickyBottom;

      if (isStickyTop || isStickyBottom) {
        var height = 0;
        var width = 0;

        if (this.$refs.nonStickyContent && this.$refs.nonStickyContent.firstElementChild) {
          height = this.$refs.nonStickyContent.offsetHeight;
          width = this.$refs.nonStickyContent.firstElementChild.scrollWidth + (this.$refs.nonStickyContent.firstElementChild.offsetWidth - this.$refs.nonStickyContent.firstElementChild.clientWidth);
        }

        return {
          height: height,
          width: width
        };
      } else {
        return {};
      }
    }
  }, {
    key: "_onScrollEvent",
    value: function _onScrollEvent(container, footerStickyContainer) {
      if (this.$refs.root && this.$refs.nonStickyContent) {
        var distanceFromTop = this._getNonStickyDistanceFromTop(container);

        var isStickyTop = false;
        var isStickyBottom = false;

        if (this.canStickyTop) {
          var distanceToStickTop = distanceFromTop - this._getStickyDistanceFromTop();

          isStickyTop = distanceToStickTop < container.scrollTop;
        }

        if (this.canStickyBottom && container.clientHeight - footerStickyContainer.offsetHeight <= distanceFromTop) {
          isStickyBottom = distanceFromTop - Math.floor(container.scrollTop) >= this._getStickyDistanceFromTopForFooter(container, footerStickyContainer);
        }

        if (document.activeElement && this.$refs.nonStickyContent.contains(document.activeElement) && (this.isStickyTop !== isStickyTop || this.isStickyBottom !== isStickyBottom)) {
          this.activeElement = document.activeElement;
        } else {
          this.activeElement = undefined;
        }

        this.isStickyTop = this.canStickyTop && isStickyTop;
        this.isStickyBottom = isStickyBottom;
        this.distanceFromTop = distanceFromTop;
      }
    }
  }, {
    key: "_getStickyDistanceFromTop",
    value: function _getStickyDistanceFromTop() {
      var distance = 0;

      if (this.$refs.stickyContentTop) {
        distance = this.$refs.stickyContentTop.offsetTop;
      }

      return distance;
    }
  }, {
    key: "_getStickyDistanceFromTopForFooter",
    value: function _getStickyDistanceFromTopForFooter(container, footerStickyVisibleContainer) {
      var distance = 0;

      if (this.$refs.stickyContentBottom) {
        distance = container.clientHeight - footerStickyVisibleContainer.offsetHeight + this.$refs.stickyContentBottom.offsetTop;
      }

      return distance;
    }
  }, {
    key: "_getNonStickyDistanceFromTop",
    value: function _getNonStickyDistanceFromTop(container) {
      var distance = 0;
      var currElem = this.$refs.root;

      if (currElem) {
        while (currElem && currElem.offsetParent !== container) {
          distance += currElem.offsetTop;
          currElem = currElem.offsetParent;
        }

        if (currElem && currElem.offsetParent === container) {
          distance += currElem.offsetTop;
        }
      }

      return distance;
    }
  }, {
    key: "_getBackground",
    value: function _getBackground() {
      if (!this.$refs.root) {
        return undefined;
      }

      var curr = this.$refs.root;

      while (window.getComputedStyle(curr).getPropertyValue('background-color') === 'rgba(0, 0, 0, 0)' || window.getComputedStyle(curr).getPropertyValue('background-color') === 'transparent') {
        if (curr.tagName === 'HTML') {
          return undefined;
        }

        if (curr.parentElement) {
          curr = curr.parentElement;
        }
      }

      return window.getComputedStyle(curr).getPropertyValue('background-color');
    }
  }, {
    key: "canStickyTop",
    get: function get() {
      return this.stickyPosition === StickyPositionType.Both || this.stickyPosition === StickyPositionType.Header;
    }
  }, {
    key: "canStickyBottom",
    get: function get() {
      return this.stickyPosition === StickyPositionType.Both || this.stickyPosition === StickyPositionType.Footer;
    }
  }]);

  return Sticky;
}(BaseComponent);

__decorate([Inject({
  from: 'context',
  default: undefined
}), __metadata("design:type", Object)], Sticky.prototype, "context", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], Sticky.prototype, "stickyClassName", void 0);

__decorate([Prop({
  type: String,
  default: null
}), __metadata("design:type", String)], Sticky.prototype, "stickyBackgroundColor", void 0);

__decorate([Prop({
  type: Number,
  default: StickyPositionType.Both
}), __metadata("design:type", Number)], Sticky.prototype, "stickyPosition", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], Sticky.prototype, "isScrollSynced", void 0);

__decorate([Watch('distanceFromTop'), __metadata("design:type", Function), __metadata("design:paramtypes", [Number, Number]), __metadata("design:returntype", void 0)], Sticky.prototype, "onDistanceFromTopChanged", null);

__decorate([Watch('isStickyTop'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], Sticky.prototype, "onIsStickyTopChanged", null);

__decorate([Watch('isStickyBottom'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean, Boolean]), __metadata("design:returntype", void 0)], Sticky.prototype, "onIsStickyBottomChanged", null);

Sticky = __decorate([Component({})], Sticky);

export { Sticky };
